Trait flexi_parse::token::Punct
source · pub trait Punct: Token { }Expand description
A trait for punctuation tokens.
This trait is sealed, and cannot be implemented by types outside of this crate.
pub trait Punct: Token { }A trait for punctuation tokens.
This trait is sealed, and cannot be implemented by types outside of this crate.